# frozen_string_literal: true

# Copyright 2021 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!

require "helper"

require "gapic/grpc/service_stub"

require "google/appengine/v1/appengine_pb"
require "google/appengine/v1/appengine_services_pb"
require "google/cloud/app_engine/v1/domain_mappings"

class ::Google::Cloud::AppEngine::V1::DomainMappings::ClientTest < Minitest::Test
  class ClientStub
    attr_accessor :call_rpc_count, :requests

    def initialize response, operation, &block
      @response = response
      @operation = operation
      @block = block
      @call_rpc_count = 0
      @requests = []
    end

    def call_rpc *args, **kwargs
      @call_rpc_count += 1

      @requests << @block&.call(*args, **kwargs)

      yield @response, @operation if block_given?

      @response
    end
  end

  def test_list_domain_mappings
    # Create GRPC objects.
    grpc_response = ::Google::Cloud::AppEngine::V1::ListDomainMappingsResponse.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    parent = "hello world"
    page_size = 42
    page_token = "hello world"

    list_domain_mappings_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :list_domain_mappings, name
      assert_kind_of ::Google::Cloud::AppEngine::V1::ListDomainMappingsRequest, request
      assert_equal "hello world", request["parent"]
      assert_equal 42, request["page_size"]
      assert_equal "hello world", request["page_token"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, list_domain_mappings_client_stub do
      # Create client
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.list_domain_mappings({ parent: parent, page_size: page_size, page_token: page_token }) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.list_domain_mappings parent: parent, page_size: page_size, page_token: page_token do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.list_domain_mappings ::Google::Cloud::AppEngine::V1::ListDomainMappingsRequest.new(parent: parent, page_size: page_size, page_token: page_token) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.list_domain_mappings({ parent: parent, page_size: page_size, page_token: page_token }, grpc_options) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.list_domain_mappings(::Google::Cloud::AppEngine::V1::ListDomainMappingsRequest.new(parent: parent, page_size: page_size, page_token: page_token), grpc_options) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, list_domain_mappings_client_stub.call_rpc_count
    end
  end

  def test_get_domain_mapping
    # Create GRPC objects.
    grpc_response = ::Google::Cloud::AppEngine::V1::DomainMapping.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    name = "hello world"

    get_domain_mapping_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :get_domain_mapping, name
      assert_kind_of ::Google::Cloud::AppEngine::V1::GetDomainMappingRequest, request
      assert_equal "hello world", request["name"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, get_domain_mapping_client_stub do
      # Create client
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.get_domain_mapping({ name: name }) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.get_domain_mapping name: name do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.get_domain_mapping ::Google::Cloud::AppEngine::V1::GetDomainMappingRequest.new(name: name) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.get_domain_mapping({ name: name }, grpc_options) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.get_domain_mapping(::Google::Cloud::AppEngine::V1::GetDomainMappingRequest.new(name: name), grpc_options) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, get_domain_mapping_client_stub.call_rpc_count
    end
  end

  def test_create_domain_mapping
    # Create GRPC objects.
    grpc_response = ::Google::Longrunning::Operation.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    parent = "hello world"
    domain_mapping = {}
    override_strategy = :UNSPECIFIED_DOMAIN_OVERRIDE_STRATEGY

    create_domain_mapping_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :create_domain_mapping, name
      assert_kind_of ::Google::Cloud::AppEngine::V1::CreateDomainMappingRequest, request
      assert_equal "hello world", request["parent"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Cloud::AppEngine::V1::DomainMapping), request["domain_mapping"]
      assert_equal :UNSPECIFIED_DOMAIN_OVERRIDE_STRATEGY, request["override_strategy"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, create_domain_mapping_client_stub do
      # Create client
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.create_domain_mapping({ parent: parent, domain_mapping: domain_mapping, override_strategy: override_strategy }) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.create_domain_mapping parent: parent, domain_mapping: domain_mapping, override_strategy: override_strategy do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.create_domain_mapping ::Google::Cloud::AppEngine::V1::CreateDomainMappingRequest.new(parent: parent, domain_mapping: domain_mapping, override_strategy: override_strategy) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.create_domain_mapping({ parent: parent, domain_mapping: domain_mapping, override_strategy: override_strategy }, grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.create_domain_mapping(::Google::Cloud::AppEngine::V1::CreateDomainMappingRequest.new(parent: parent, domain_mapping: domain_mapping, override_strategy: override_strategy), grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, create_domain_mapping_client_stub.call_rpc_count
    end
  end

  def test_update_domain_mapping
    # Create GRPC objects.
    grpc_response = ::Google::Longrunning::Operation.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    name = "hello world"
    domain_mapping = {}
    update_mask = {}

    update_domain_mapping_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :update_domain_mapping, name
      assert_kind_of ::Google::Cloud::AppEngine::V1::UpdateDomainMappingRequest, request
      assert_equal "hello world", request["name"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Cloud::AppEngine::V1::DomainMapping), request["domain_mapping"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Protobuf::FieldMask), request["update_mask"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, update_domain_mapping_client_stub do
      # Create client
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.update_domain_mapping({ name: name, domain_mapping: domain_mapping, update_mask: update_mask }) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.update_domain_mapping name: name, domain_mapping: domain_mapping, update_mask: update_mask do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.update_domain_mapping ::Google::Cloud::AppEngine::V1::UpdateDomainMappingRequest.new(name: name, domain_mapping: domain_mapping, update_mask: update_mask) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.update_domain_mapping({ name: name, domain_mapping: domain_mapping, update_mask: update_mask }, grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.update_domain_mapping(::Google::Cloud::AppEngine::V1::UpdateDomainMappingRequest.new(name: name, domain_mapping: domain_mapping, update_mask: update_mask), grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, update_domain_mapping_client_stub.call_rpc_count
    end
  end

  def test_delete_domain_mapping
    # Create GRPC objects.
    grpc_response = ::Google::Longrunning::Operation.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    name = "hello world"

    delete_domain_mapping_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :delete_domain_mapping, name
      assert_kind_of ::Google::Cloud::AppEngine::V1::DeleteDomainMappingRequest, request
      assert_equal "hello world", request["name"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, delete_domain_mapping_client_stub do
      # Create client
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.delete_domain_mapping({ name: name }) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.delete_domain_mapping name: name do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.delete_domain_mapping ::Google::Cloud::AppEngine::V1::DeleteDomainMappingRequest.new(name: name) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.delete_domain_mapping({ name: name }, grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.delete_domain_mapping(::Google::Cloud::AppEngine::V1::DeleteDomainMappingRequest.new(name: name), grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, delete_domain_mapping_client_stub.call_rpc_count
    end
  end

  def test_configure
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure

    client = block_config = config = nil
    Gapic::ServiceStub.stub :new, nil do
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end
    end

    config = client.configure do |c|
      block_config = c
    end

    assert_same block_config, config
    assert_kind_of ::Google::Cloud::AppEngine::V1::DomainMappings::Client::Configuration, config
  end

  def test_operations_client
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure

    client = nil
    Gapic::ServiceStub.stub :new, nil do
      client = ::Google::Cloud::AppEngine::V1::DomainMappings::Client.new do |config|
        config.credentials = grpc_channel
      end
    end

    assert_kind_of ::Google::Cloud::AppEngine::V1::DomainMappings::Operations, client.operations_client
  end
end
